<h1>Python cache cleaner</h1>

<p>Python cache cleaner is simple CLI's tool for which remove python cache from folders and projects</p>

<h1>Installation</h1>

<h4>Using <i>git</i></h4>

```
$ git clone https://github.com/whyme0/pyc_cleaner
$ cd ./pyc_cleaner/src/
$ python3 ./main.py --path "PATH/TO/YOUR/PROJECT" --show_log "y"
```